1.0.0 API documentation: matrix_float2x4_precision.hpp File Reference

| 1.0.0 API documentation

Typedefs
matrix_float2x4_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 2, 4, float, highp > | highp_mat2x4
| 2 columns of 4 components matrix of single-precision floating-point numbers using high precision arithmetic in term of ULPs. More...
typedef mat< 2, 4, float, lowp > | lowp_mat2x4
| 2 columns of 4 components matrix of single-precision floating-point numbers using low precision arithmetic in term of ULPs. More...
typedef mat< 2, 4, float, mediump > | mediump_mat2x4
| 2 columns of 4 components matrix of single-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...

## Detailed Description

Core features

Definition in file matrix_float2x4_precision.hpp.